@@ -21,4 +21,9 @@ from oc_idmanager.isbn import ISBNManager
 from oc_idmanager.issn import ISSNManager
 from oc_idmanager.orcid import ORCIDManager
 from oc_idmanager.pmid import PMIDManager
-from oc_idmanager.wikidata import WikidataManager
\ No newline at end of file
+from oc_idmanager.wikidata import WikidataManager
+from oc_idmanager.wikipedia import WikipediaManager
+from oc_idmanager.url import URLManager
+from oc_idmanager.viaf import ViafManager
+from oc_idmanager.ror import RORManager
+from oc_idmanager.pmcid import PMCIDManager
